@@ -1,4 +1,6 @@
-from dvc.utils.diff import format_dict, diff as _diff
+from dvc.utils.diff import diff as _diff
+from dvc.utils.diff import format_dict
+
 from .show import NoParamsError
 
 
@@ -11,6 +13,9 @@ def _get_params(repo, *args, rev=None, **kwargs):
 
 
 def diff(repo, *args, a_rev=None, b_rev=None, **kwargs):
+    if repo.scm.no_commits:
+        return {}
+
     with_unchanged = kwargs.pop("all", False)
 
     old = _get_params(repo, *args, **kwargs, rev=(a_rev or "HEAD"))
